@@ -247,6 +247,8 @@ def hhclub_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
             }
 
     scraper=cloudscraper.create_scraper()
+    success_upload=0
+    try_upload=0
     while success_upload==0:
         try_upload+=1
         if try_upload>5:
